@@ -19,8 +19,10 @@ from .constants import BLOCK_SIZE_BYTES, EVTH_VERSION_POSITION
 
 Event = namedtuple('Event', ['header', 'data', 'longitudinal', 'end'])
 PhotonEvent = namedtuple('PhotonEvent', ['header', 'photons', 'longitudinal', 'end'])
-ParticleEvent = namedtuple('ParticleEvent', ['header', 'particles', 'longitudinal', 'end'])
-
+ParticleEvent = namedtuple(
+    'ParticleEvent',
+    ['header', 'particles', 'longitudinal', 'end']
+)
 
 
 class CorsikaFile:
@@ -67,18 +69,15 @@ class CorsikaFile:
             self._run_end = parse_run_end(block)
             raise StopIteration()
 
-        if len(block) < BLOCK_SIZE_BYTES:
-            raise StopIteration
-
         if block[:4] != b'EVTH':
             raise IOError('EVTH block expected but found {}'.format(block[:4]))
 
         event_header = parse_event_header(block)[0]
 
-        block = self.read_block()
         data_bytes = bytearray()
         long_bytes = bytearray()
 
+        block = self.read_block()
         while block[:4] != b'EVTE':
 
             if block[:4] == b'LONG':
@@ -115,7 +114,10 @@ class CorsikaFile:
                 self._run_end = parse_run_end(block)[0]
                 break
 
-            if block[:4] == b'EVTH' and get_version(block, EVTH_VERSION_POSITION) == self.version:
+            if (
+                block[:4] == b'EVTH'
+                and get_version(block, EVTH_VERSION_POSITION) == self.version
+            ):
                 if not end_found:
                     raise IOError('Expected EVTE block before next EVTH')
 
